@@ -1,14 +1,12 @@
 import torch
 from .model import Model
-from .modules import Linear, default_module_settings, get_module_settings
+from .modules import Linear
 
 
 class Classifier(Model):
-    @default_module_settings(multilabel=False)
-    def __init__(self, model, num_classes):
+    def __init__(self, model, num_classes, multilabel=False):
         super().__init__(num_classes)
-        settings = get_module_settings()
-        is_multiclass = not settings['multilabel']
+        is_multiclass = not multilabel
 
         self.base_model = model
         self.classifier = Linear(model.output_dim, num_classes)
