@@ -1,6 +1,6 @@
 from .activation import HardSwish, HardSigmoid
 from .addition import Add
-from .base import ModuleBase, default_module_settings, set_module_settings, get_module_settings
+from .base import ModuleBase
 from .convolution import Conv2dBN, Conv2dAct, Conv2d
 from .depthwise_separable_conv import DepthwiseSeparableConv2d
 from .focal_loss import FocalLoss
@@ -14,7 +14,7 @@ from .shuffle import ChannelShuffle
 from .ssd_loss import SSDLoss, SSDSigmoidLoss
 from .ssd_predictor import SSDPredictor, SSDSigmoidPredictor
 
-__all__ = ['HardSwish', 'HardSigmoid', 'Add', 'ModuleBase', 'default_module_settings', 'set_module_settings', 'get_module_settings',
+__all__ = ['HardSwish', 'HardSigmoid', 'Add', 'ModuleBase',
            'Conv2dBN', 'Conv2dAct', 'Conv2d', 'DepthwiseSeparableConv2d',
            'FocalLoss', 'LinearAct', 'Linear', 'MBConv', 'PriorBox', 'RetinaPredictor', 'RetinaPriorBox', 'SEBlock',
            'ChannelShuffle', 'SSDLoss', 'SSDSigmoidLoss', 'SSDPredictor', 'SSDSigmoidPredictor']
