@@ -1,20 +1,19 @@
 """Squeeze-and-Excitation (SE) block (https://arxiv.org/abs/1709.01507)"""
 import torch
-from .base import ModuleBase, default_module_settings
+from .base import ModuleBase
 from .activation import HardSigmoid, Swish, HardSwish
 
 
 class SEBlock(ModuleBase):
-    @default_module_settings(activation='relu', use_hsigmoid=False)
-    def __init__(self, in_channels, reduction_ratio, **kwargs):
-        super().__init__(**kwargs)
+    def __init__(self, in_channels, reduction_ratio, activation='relu', use_hsigmoid=False):
+        super().__init__()
 
         self.in_channels = in_channels
         self.pool = torch.nn.AdaptiveAvgPool2d(1)
         self.conv0 = torch.nn.Conv2d(in_channels, in_channels // reduction_ratio, kernel_size=1)
-        self._set_activation(self.module_settings['activation'])
+        self._set_activation(activation)
         self.conv1 = torch.nn.Conv2d(in_channels // reduction_ratio, in_channels, kernel_size=1)
-        self.sigmoid = HardSigmoid() if self.module_settings['use_hsigmoid'] else torch.nn.Sigmoid()
+        self.sigmoid = HardSigmoid() if use_hsigmoid else torch.nn.Sigmoid()
 
     def _set_activation(self, act):
         assert act in ['relu', 'hswish', 'swish', 'relu6', 'none']
