@@ -2,7 +2,7 @@
 import collections
 import torch
 from .model import Model
-from .modules import Conv2dAct, Conv2dBN, SEBlock, ChannelShuffle, default_module_settings
+from .modules import Conv2dAct, Conv2dBN, SEBlock, ChannelShuffle
 
 
 class ShuffleNetV2(Model):
@@ -59,7 +59,6 @@ class ShuffleNetV2(Model):
             x = torch.cat((x2, x1), 1)
             return self.shuffle(x)
 
-    @default_module_settings(use_bn=True)
     def __init__(self, channels_scaler=1.0, num_blocks=[4, 8, 4], use_se=False):
         first_in_channels = ShuffleNetV2.FIRST_STAGE_CHANNELS[channels_scaler]
         last_stage_out_channels = first_in_channels * (2 ** (len(num_blocks) - 1))
